@@ -451,7 +451,8 @@ enum
     CODECHAL_ENCODE_PERFTAG_CALL_BRC_UPDATE_SECOND_PASS,
     CODECHAL_ENCODE_PERFTAG_CALL_HEVC_LA_UPDATE,
     CODECHAL_ENCODE_PERFTAG_CALL_VP9_HPU,
-    CODECHAL_ENCODE_PERFTAG_CALL_VP9_HPU_SECOND_PASS
+    CODECHAL_ENCODE_PERFTAG_CALL_VP9_HPU_SECOND_PASS,
+    CODECHAL_ENCODE_PERFTAG_CALL_RSVD,
 };
 
 typedef enum _CODECHAL_ENCODE_FUNCTION_ID
