@@ -397,6 +397,9 @@ typedef enum _MEDIA_EVENT
     EVENT_DECODE_IP_ALIGNMENT,                     //! event for Decode IP Alignment
     EVENT_ENCODE_IP_ALIGNMENT,                     //! event for Encode IP Alignment
     EVENT_VPP_IP_ALIGNMENT,                        //! event for VPP IP Alignment
+    EVENT_IP_ALIGNMENT_INIT,                       //! event for IP Alignment Init
+    EVENT_IP_ALIGNMENT_REPORT,                     //! event for IP Alignment Report
+    EVENT_ENCODE_DDI_11_DESTROYVIDEOENCODER        //! event for Encode Destroy Device
 } MEDIA_EVENT;
 
 typedef enum _MEDIA_EVENT_TYPE
@@ -407,12 +410,9 @@ typedef enum _MEDIA_EVENT_TYPE
     EVENT_TYPE_INFO2 = 3,           //! function extra information event
 } MEDIA_EVENT_TYPE;
 
-typedef enum _MT_LEVEL
-{
-    MT_VERBOSE  = 0,  //! verbos runtime log
-    MT_NORMAL   = 1,  //! normal runtime log
-    MT_CRITICAL = 2,  //! critical runtime log
-} MT_LEVEL;
+#define MT_CRITICAL ((int32_t)MT_LOG_LEVEL::CRITICAL)  //! critical runtime log
+#define MT_NORMAL   ((int32_t)MT_LOG_LEVEL::NORMAL)    //! normal runtime log
+#define MT_VERBOSE  ((int32_t)MT_LOG_LEVEL::VERBOSE)   //! verbos runtime log
 
 class MtEnable
 {
@@ -803,6 +803,7 @@ typedef enum _MT_LOG_ID
     MT_VP_MHW_VE_SURFSTATE_STMM,
     MT_VP_MHW_VE_SCALABILITY,
     MT_VP_MHW_VE_ADJUST_SURFPARAM,
+    MT_VP_MHW_CACHE_MOCS_TABLE,
     MT_VP_KERNEL_ID_BASE = 0x02003000,
     MT_VP_KERNEL_CSC,
     MT_VP_KERNEL_RULE,
@@ -902,6 +903,7 @@ typedef enum _MT_PARAM_ID
     MT_SYNC_LAST_FENCE_TAG,
     MT_SYNC_WAIT_BEFORE_SYNC,
     MT_SYNC_WAIT_MICROSECOND,
+    MT_SYNC_WAIT_RESULT,
     MT_PARAM_ID_CP_BASE  = 0x01000000,
     MT_CP_SESSION_TYPE,
     MT_CP_SESSION_MODE,
@@ -965,6 +967,8 @@ typedef enum _MT_PARAM_ID
     MT_VP_BLT_FDFBPARAM_FACECOUNT,
     MT_VP_BLT_FDFBPARAM_FBMAXFACECOUNT,
     MT_VP_BLT_SR_MODE,
+    MT_VP_BLT_SR_EU,
+    MT_VP_BLT_SR_GEN,
     MT_PARAM_ID_VP_HAL_BASE = 0x02000400,
     MT_VP_HAL_APO,
     MT_VP_HAL_PTR,
@@ -1134,6 +1138,12 @@ typedef enum _MT_PARAM_ID
     MT_VP_MHW_VE_SCALABILITY_EN,
     MT_VP_MHW_VE_SCALABILITY_USE_SFC,
     MT_VP_MHW_VE_SCALABILITY_IDX,
+    MT_VP_MHW_CACHE_MEMORY_OBJECT_CONTROL_STATE,
+    MT_VP_MHW_CACHE_MEMORY_OBJECT_NAME,
+    MT_VP_MHW_CACHE_MEMORY_OBJECT_SURFACE_TYPE,
+    MT_VP_MHW_CACHE_MEMORY_OBJECT_SURFACE_WIDTH,
+    MT_VP_MHW_CACHE_MEMORY_OBJECT_SURFACE_HEIGHT,
+    MT_VP_MHW_CACHE_MEMORY_OBJECT_SURFACE_FORMAT,
     MT_PARAM_ID_VP_KERNEL_BASE = 0x02003000,
     MT_VP_KERNEL_CSPACE, 
     MT_VP_KERNEL_RULE_ID,
