@@ -516,6 +516,7 @@ MOS_STATUS CodecHalDecodeScalability_InitScalableParams_G12(
         bCanEnableRealTile = bCanEnableRealTile && pInitParams->bIsTileEnabled && (pInitParams->u8NumTileColumns > 1) &&
             (pInitParams->u8NumTileColumns <= u8MaxTileColumn) && (pInitParams->u8NumTileRows <= HEVC_NUM_MAX_TILE_ROW) &&
             pInitParams->bHasSubsetParams;
+        
         if (bCanEnableRealTile)
         {
             pScalabilityState->bIsRtMode = true;
@@ -1588,6 +1589,11 @@ bool CodecHalDecodeScalability_DecideEnableScala_G12(
     {
         bEnableScala = true;
     }
+    else if(MEDIA_IS_SKU(pScalState->pHwInterface->GetSkuTable(), FtrVirtualTileScalabilityDisable))
+    {
+        bEnableScala = false;
+        CODECHAL_DECODE_NORMALMESSAGE(" Disable VT Scalability according to platform SKU");
+    }
     else
     {
         // NonRextFormat && >=5k - VT Scalability
