@@ -1230,11 +1230,11 @@ public:
     bool                                  m_enableFramePanicMode = true;   //!< Flag to control frame panic feature
 
     // HuC PAK stitch kernel
-    bool                                        m_hucPakStitchEnabled = false;                                //!< HuC PAK stitch enabled flag
-    MOS_RESOURCE                                m_resHucPakStitchDmemBuffer[CODECHAL_ENCODE_RECYCLED_BUFFER_NUM][CODECHAL_DP_MAX_NUM_BRC_PASSES];  //!< HuC Pak Integration Dmem data for each pass
-    MOS_RESOURCE                                m_resBrcDataBuffer;                                           //!< Resource of bitrate control data buffer
-    MOS_RESOURCE                                m_resHucStitchDataBuffer[CODECHAL_ENCODE_RECYCLED_BUFFER_NUM][CODECHAL_HEVC_MAX_NUM_BRC_PASSES];  // data buffer for huc input cmd generation
-    MHW_BATCH_BUFFER                            m_HucStitchCmdBatchBuffer = {};             //!< SLB for huc stitch cmd
+    bool                                        m_hucPakStitchEnabled     = false;                                                                      //!< HuC PAK stitch enabled flag
+    MOS_RESOURCE                                m_resHucPakStitchDmemBuffer[CODECHAL_ENCODE_RECYCLED_BUFFER_NUM][CODECHAL_DP_MAX_NUM_BRC_PASSES] = {};  //!< HuC Pak Integration Dmem data for each pass
+    MOS_RESOURCE                                m_resBrcDataBuffer        = {};                                                                         //!< Resource of bitrate control data buffer
+    MOS_RESOURCE                                m_resHucStitchDataBuffer[CODECHAL_ENCODE_RECYCLED_BUFFER_NUM][CODECHAL_HEVC_MAX_NUM_BRC_PASSES]  = {};  // data buffer for huc input cmd generation
+    MHW_BATCH_BUFFER                            m_HucStitchCmdBatchBuffer = {};                                                                         //!< SLB for huc stitch cmd
 
     // BRC panic mode
     struct SkipFrameInfo
@@ -1475,7 +1475,7 @@ public:
 
     MOS_STATUS SubmitCommandBuffer(
         PMOS_COMMAND_BUFFER cmdBuffer,
-        bool  nullRendering) override;
+        bool  bNullRendering) override;
 
     MOS_STATUS SetSliceStructs() override;
 
