@@ -142,7 +142,7 @@ MOS_STATUS MhwInterfacesG12Tgllp::Initialize(
     CreateParams params,
     PMOS_INTERFACE osInterface)
 {
-#ifdef IGFX_VDENC_INTERFACE_EXT_SUPPORT
+#ifdef _MEDIA_RESERVED
     bool useBaseVdencInterface = false;
 #if (_DEBUG || _RELEASE_INTERNAL)
     MOS_USER_FEATURE_VALUE_DATA     UserFeatureData;
@@ -280,7 +280,7 @@ MOS_STATUS MhwInterfacesG12Tgllp::Initialize(
     }
     if (params.Flags.m_vdboxAll || params.Flags.m_vdenc)
     {
-#ifdef IGFX_VDENC_INTERFACE_EXT_SUPPORT
+#ifdef _MEDIA_RESERVED
 #if (_DEBUG || _RELEASE_INTERNAL)
         if(useBaseVdencInterface)
         {
@@ -333,7 +333,6 @@ void MhwInterfacesG12Tgllp::Destroy()
     }
 }
 
-#ifdef _MMC_SUPPORTED
 static bool tgllpRegisteredMmd =
     MediaFactory<uint32_t, MmdDevice>::
     Register<MmdDeviceG12Tgllp>((uint32_t)IGFX_TIGERLAKE_LP);
@@ -402,55 +401,58 @@ MhwInterfaces* MmdDeviceG12Tgllp::CreateMhwInterface(
 
     return mhw;
 }
-#endif
 
 static bool tgllpRegisteredMcpy =
     MediaFactory<uint32_t, McpyDevice>::
     Register<McpyDeviceG12Tgllp>((uint32_t)IGFX_TIGERLAKE_LP);
 
 MOS_STATUS McpyDeviceG12Tgllp::Initialize(
-    PMOS_INTERFACE osInterface,
-    MhwInterfaces *mhwInterfaces)
+    PMOS_INTERFACE osInterface)
 {
-#define MCPY_FAILURE()                                       \
-{                                                           \
-    if (device != nullptr)                                  \
-    {                                                       \
-        MOS_Delete(device);                                 \
-    }                                                       \
-    return MOS_STATUS_NO_SPACE;                             \
-}
-
     MHW_FUNCTION_ENTER;
 
     Mcpy *device = nullptr;
+    MhwInterfaces* mhwInterfaces = nullptr;
 
-    if (mhwInterfaces->m_miInterface == nullptr)
-    {
-        MCPY_FAILURE();
-    }
+    auto deleterOnFailure = [&](bool deleteOsInterface, bool deleteMhwInterface){
+        if (deleteOsInterface && osInterface != nullptr)
+        {
+            if (osInterface->pfnDestroy)
+            {
+                osInterface->pfnDestroy(osInterface, false);
+            }
+            MOS_FreeMemory(osInterface);
+        }
 
-    if (mhwInterfaces->m_veboxInterface == nullptr)
-    {
-        MCPY_FAILURE();
-    }
+        if (deleteMhwInterface && mhwInterfaces != nullptr)
+        {
+            mhwInterfaces->Destroy();
+            MOS_Delete(mhwInterfaces);
+        }
 
-    if (mhwInterfaces->m_bltInterface == nullptr)
-    {
-        MCPY_FAILURE();
-    }
+        MOS_Delete(device);
+    };
 
     device = MOS_New(Mcpy);
-
     if (device == nullptr)
     {
-        MCPY_FAILURE();
+        deleterOnFailure(true, false);
+        return MOS_STATUS_NO_SPACE;
+    }
+
+    mhwInterfaces = CreateMhwInterface(osInterface);
+    if (mhwInterfaces->m_miInterface == nullptr ||
+        mhwInterfaces->m_veboxInterface == nullptr ||
+        mhwInterfaces->m_bltInterface == nullptr)
+    {
+        deleterOnFailure(true, true);
+        return MOS_STATUS_NO_SPACE;
     }
 
     if (device->Initialize(
         osInterface, mhwInterfaces) != MOS_STATUS_SUCCESS)
     {
-        MOS_Delete(device);
+        deleterOnFailure(false, false);
         MOS_OS_CHK_STATUS_RETURN(MOS_STATUS_UNINITIALIZED);
     }
 
@@ -567,7 +569,7 @@ MOS_STATUS CodechalInterfacesG12Tgllp::Initialize(
         if (info->Mode == CODECHAL_DECODE_MODE_MPEG2IDCT ||
             info->Mode == CODECHAL_DECODE_MODE_MPEG2VLD)
         {
-        #ifdef _APOGEIOS_SUPPORTED
+        #ifdef _MEDIA_RESERVED
             bool apogeiosEnable = false;
             MOS_USER_FEATURE_VALUE_DATA         userFeatureData;
             MOS_ZeroMemory(&userFeatureData, sizeof(userFeatureData));
@@ -605,7 +607,7 @@ MOS_STATUS CodechalInterfacesG12Tgllp::Initialize(
         if (info->Mode == CODECHAL_DECODE_MODE_AVCVLD)
         {
             bool apogeiosEnable = false;
-        #ifdef _APOGEIOS_SUPPORTED
+        #ifdef _MEDIA_RESERVED
             MOS_USER_FEATURE_VALUE_DATA         userFeatureData;
             MOS_ZeroMemory(&userFeatureData, sizeof(userFeatureData));
 
@@ -664,7 +666,7 @@ MOS_STATUS CodechalInterfacesG12Tgllp::Initialize(
         if (info->Mode == CODECHAL_DECODE_MODE_JPEG)
         {
             bool apogeiosEnable = false;
-#ifdef _APOGEIOS_SUPPORTED
+#ifdef _MEDIA_RESERVED
             MOS_USER_FEATURE_VALUE_DATA userFeatureData;
             MOS_ZeroMemory(&userFeatureData, sizeof(userFeatureData));
 
@@ -699,7 +701,7 @@ MOS_STATUS CodechalInterfacesG12Tgllp::Initialize(
     #ifdef _HEVC_DECODE_SUPPORTED
         if (info->Mode == CODECHAL_DECODE_MODE_HEVCVLD)
         {
-            #ifdef _APOGEIOS_SUPPORTED
+            #ifdef _MEDIA_RESERVED
             bool apogeiosEnable = false;
             MOS_USER_FEATURE_VALUE_DATA         userFeatureData;
             MOS_ZeroMemory(&userFeatureData, sizeof(userFeatureData));
@@ -728,7 +730,7 @@ MOS_STATUS CodechalInterfacesG12Tgllp::Initialize(
     #ifdef _VP9_DECODE_SUPPORTED
         if (info->Mode == CODECHAL_DECODE_MODE_VP9VLD)
         {
-#ifdef _APOGEIOS_SUPPORTED
+#ifdef _MEDIA_RESERVED
             bool                        apogeiosEnable = false;
             MOS_USER_FEATURE_VALUE_DATA userFeatureData;
             MOS_ZeroMemory(&userFeatureData, sizeof(userFeatureData));
