@@ -39,15 +39,13 @@ public:
 
     virtual ~VpVeboxCmdPacketXe_Hpm();
 
-MEDIA_CLASS_DEFINE_END(VpVeboxCmdPacketXe_Hpm)
-
     virtual MOS_STATUS AddVeboxDndiState() override;
 
     virtual MOS_STATUS QueryStatLayoutGNE(
         VEBOX_STAT_QUERY_TYPE QueryType,
         uint32_t             *pQuery,
         uint8_t              *pStatSlice0Base,
-        uint8_t              *pStatSlice1Base);
+        uint8_t              *pStatSlice1Base) override;
 
     virtual MOS_STATUS CheckTGNEValid(
         uint32_t *pStatSlice0GNEPtr,
@@ -56,10 +54,10 @@ MEDIA_CLASS_DEFINE_END(VpVeboxCmdPacketXe_Hpm)
 
     virtual MOS_STATUS UpdateDnHVSParameters(
         uint32_t *pStatSlice0GNEPtr,
-        uint32_t *pStatSlice1GNEPtr);
+        uint32_t *pStatSlice1GNEPtr) override;
 
     virtual MOS_STATUS SetupDNTableForHVS(
-        PMHW_VEBOX_STATE_CMD_PARAMS pVeboxStateCmdParams);
+        PMHW_VEBOX_STATE_CMD_PARAMS pVeboxStateCmdParams) override;
 
     MOS_STATUS GNELumaConsistentCheck(
         uint32_t &dwGNELuma,
@@ -78,6 +76,7 @@ MEDIA_CLASS_DEFINE_END(VpVeboxCmdPacketXe_Hpm)
 
     MhwVeboxInterfaceG12::MHW_VEBOX_CHROMA_PARAMS veboxChromaParams = {};
 
+MEDIA_CLASS_DEFINE_END(vp__VpVeboxCmdPacketXe_Hpm)
 };
 
 }
