@@ -31,6 +31,8 @@
 #include "decode_mpeg2_pipeline.h"
 #include "decode_utils.h"
 #include "decode_mpeg2_basic_feature.h"
+#include "mhw_vdbox_g12_X.h"
+#include "codechal_hw_g12_X.h"
 
 namespace decode {
 
@@ -41,10 +43,13 @@ namespace decode {
         //! \brief  Mpeg2DecodePicPktXe_M_Base constructor
         //!
         Mpeg2DecodePicPktXe_M_Base(Mpeg2Pipeline *pipeline, CodechalHwInterface *hwInterface)
-            : DecodeSubPacket(pipeline, hwInterface), m_mpeg2Pipeline(pipeline)
+            : DecodeSubPacket(pipeline, *hwInterface), m_mpeg2Pipeline(pipeline)
         {
+            m_hwInterface = hwInterface;
             if (m_hwInterface != nullptr)
             {
+                m_miInterface  = m_hwInterface->GetMiInterface();
+                m_osInterface  = m_hwInterface->GetOsInterface();
                 m_mfxInterface = static_cast<CodechalHwInterfaceG12*>(hwInterface)->GetMfxInterface();
             }
         }
@@ -141,6 +146,9 @@ namespace decode {
         uint32_t m_pictureStatesSize = 0;    //!< Picture states size
         uint32_t m_picturePatchListSize = 0;    //!< Picture patch list size
 
+        CodechalHwInterface *m_hwInterface = nullptr;
+        MhwMiInterface      *m_miInterface = nullptr;
+
     private:
         //!
         //! \enum  DecodeRefAddrIndex
@@ -164,7 +172,7 @@ namespace decode {
             mpeg2Vc1BottomField,
             mpeg2Vc1Frame
         };
-    MEDIA_CLASS_DEFINE_END(Mpeg2DecodePicPktXe_M_Base)
+    MEDIA_CLASS_DEFINE_END(decode__Mpeg2DecodePicPktXe_M_Base)
     };
 
 }  // namespace decode
