@@ -80,14 +80,13 @@ MOS_STATUS HevcPipeline::UserFeatureReport()
     WriteUserFeature(__MEDIA_USER_FEATURE_VALUE_APOGEIOS_HEVCD_ENABLE_ID, 1, m_osInterface->pOsContext);
 #endif
 
-#ifdef _MMC_SUPPORTED
     CODECHAL_DEBUG_TOOL(
         if (m_mmcState != nullptr)
         {
             m_mmcState->UpdateUserFeatureKey(&(m_basicFeature->m_destSurface));
         }
         );
-#endif
+
     return MOS_STATUS_SUCCESS;
 }
 
@@ -504,7 +503,7 @@ MOS_STATUS HevcPipeline::DumpSliceParams(
             if (shortFormatInUse)
             {
                 PCODEC_HEVC_SF_SLICE_PARAMS slcParamsSF =
-                    (PCODEC_HEVC_SF_SLICE_PARAMS)MOS_AllocMemory(sizeof(PCODEC_HEVC_SF_SLICE_PARAMS) * numSlices);
+                    (PCODEC_HEVC_SF_SLICE_PARAMS)MOS_AllocMemory(sizeof(CODEC_HEVC_SF_SLICE_PARAMS) * numSlices);
 
                 for (uint16_t i = 0; i < numSlices; i++)
                 {
