@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2018-2022, Intel Corporation
+* Copyright (c) 2018-2025, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -96,6 +96,7 @@ public:
     DeclareDecodePacketId(hevcPictureSubPacketId);
     DeclareDecodePacketId(hevcSliceSubPacketId);
     DeclareDecodePacketId(hevcTileSubPacketId);
+    DeclareDecodePacketId(hevcDecodeAqmId);
 
 protected:
     //!
@@ -283,7 +284,7 @@ protected:
     //! \return   MOS_STATUS
     //!           MOS_STATUS_SUCCESS if success, else fail reason
     //!
-    MOS_STATUS DumpSecondLevelBatchBuffer();
+    virtual MOS_STATUS DumpSecondLevelBatchBuffer();
 #endif
 
 protected:
