@@ -212,6 +212,28 @@ MOS_STATUS AvcBasicFeature::Update(void *params)
         m_perMBStreamOutEnable = true;
     }
 
+#if MHW_HWCMDPARSER_ENABLED
+    char frameType = '\0';
+    switch (m_picParam->CodingType)
+    {
+    case I_TYPE:
+        frameType = 'I';
+        break;
+    case P_TYPE:
+        frameType = 'P';
+        break;
+    case B_TYPE:
+        frameType = (m_picParam->RefPicFlag) ? 'B' : 'b';
+        break;
+    }
+
+    auto instance = mhw::HwcmdParser::GetInstance();
+    if (instance)
+    {
+        instance->Update(frameType, (void *)m_featureManager);
+    }
+#endif
+
     return MOS_STATUS_SUCCESS;
 }
 
@@ -259,8 +281,6 @@ MOS_STATUS AvcBasicFeature::SetSequenceStructs()
     seqParams->bit_depth_luma_minus8   = 0;
     seqParams->bit_depth_chroma_minus8 = 0;
 
-    seqParams->NumRefFrames = seqParams->NumRefFrames * 2;
-
     // setup parameters corresponding to H264 bit stream definition
     seqParams->pic_height_in_map_units_minus1       = seqParams->frame_mbs_only_flag ? CODECHAL_GET_HEIGHT_IN_MACROBLOCKS(seqParams->FrameHeight) - 1 : (CODECHAL_GET_HEIGHT_IN_MACROBLOCKS(seqParams->FrameHeight) + 1) / 2 - 1;
     seqParams->pic_width_in_mbs_minus1              = CODECHAL_GET_WIDTH_IN_MACROBLOCKS(seqParams->FrameWidth) - 1;
@@ -564,12 +584,18 @@ void AvcBasicFeature::CheckResolutionChange()
 
     uint32_t frameWidth = m_seqParam->FrameWidth;
     uint32_t frameHeight = m_seqParam->FrameHeight;
+    uint16_t frame_crop_bottom_offset = m_seqParam->frame_crop_bottom_offset;
+    uint16_t frame_mbs_only_flag      = m_seqParam->frame_mbs_only_flag;
+    uint16_t frame_cropping_flag      = m_seqParam->frame_cropping_flag;
 
     // Only for first frame
     if (m_frameNum == 0)
     {
         m_oriFrameHeight = frameHeight;
         m_oriFrameWidth = frameWidth;
+        m_frame_crop_bottom_offset = frame_crop_bottom_offset;
+        m_frame_mbs_only_flag        = frame_mbs_only_flag;
+        m_frame_cropping_flag      = frame_cropping_flag;
         m_resolutionChanged = true;
     }
     else
@@ -581,6 +607,9 @@ void AvcBasicFeature::CheckResolutionChange()
             m_resolutionChanged = true;
             m_oriFrameHeight = frameHeight;
             m_oriFrameWidth = frameWidth;
+            m_frame_crop_bottom_offset = frame_crop_bottom_offset;
+            m_frame_mbs_only_flag      = frame_mbs_only_flag;
+            m_frame_cropping_flag      = frame_cropping_flag;
         }
         else
         {
@@ -661,11 +690,19 @@ bool AvcBasicFeature::InputSurfaceNeedsExtraCopy(const MOS_SURFACE &input)
 
 MOS_STATUS AvcBasicFeature::UpdateTrackedBufferParameters()
 {
+    ENCODE_FUNC_CALL();
+    ENCODE_CHK_NULL_RETURN(m_trackedBuf);
+
+    ENCODE_CHK_STATUS_RETURN(m_trackedBuf->OnSizeChange());
+
     uint32_t fieldNumMBs = (uint32_t)m_picWidthInMb * ((m_picHeightInMb + 1) >> 1);
 
     m_mbCodeSize = MOS_ALIGN_CEIL(fieldNumMBs * 16 * 4, CODECHAL_PAGE_SIZE) + fieldNumMBs * 16 * 4;
     m_mvDataSize = 0;
-    m_colocatedMVBufferSize = (((uint32_t)m_picHeightInMb * m_picWidthInMb + 1) >> 1) * CODECHAL_CACHELINE_SIZE; // Cacheline per 2 MBs
+
+    uint32_t widthInMbRoundUp  = (m_frameWidth + 31) >> 4;
+    uint32_t heightInMbRoundUp = (m_frameHeight + 15) >> 4;
+    m_colocatedMVBufferSize    = widthInMbRoundUp * heightInMbRoundUp * CODECHAL_CACHELINE_SIZE / 2; // Cacheline per 2 MBs
 
     MOS_ALLOC_GFXRES_PARAMS allocParams;
     MOS_ZeroMemory(&allocParams, sizeof(MOS_ALLOC_GFXRES_PARAMS));
@@ -1171,7 +1208,6 @@ MHW_SETPAR_DECL_SRC(VDENC_PIPE_BUF_ADDR_STATE, AvcBasicFeature)
     params.streamOutBuffer = m_recycleBuf->GetBuffer(VdencStatsBuffer, 0);
     params.surfaceDsStage1 = m_4xDSSurface;
 
-#ifdef _MMC_SUPPORTED
         ENCODE_CHK_NULL_RETURN(m_mmcState);
         if (m_mmcState->IsMmcEnabled())
         {
@@ -1203,7 +1239,6 @@ MHW_SETPAR_DECL_SRC(VDENC_PIPE_BUF_ADDR_STATE, AvcBasicFeature)
             params.mmcStatePreDeblock = MOS_MEMCOMP_DISABLED;
             params.mmcStateRaw = MOS_MEMCOMP_DISABLED;
         }
-#endif
 
     if (m_ref->GetRefList()[m_currReconstructedPic.FrameIdx]->bUsedAsRef)
     {
@@ -1515,12 +1550,11 @@ MHW_SETPAR_DECL_SRC(MFX_SURFACE_STATE, AvcBasicFeature)
             MOS_ALIGN_CEIL((psSurface->VPlaneOffset.iSurfaceOffset - psSurface->dwOffset)/psSurface->dwPitch + psSurface->RenderOffset.YUV.V.YOffset, uvPlaneAlignment);
     }
 
-#ifdef _MMC_SUPPORTED
     if (m_mmcState && m_mmcState->IsMmcEnabled())
     {
         ENCODE_CHK_STATUS_RETURN(m_mmcState->GetSurfaceMmcFormat(psSurface, &params.compressionFormat));
     }
-#endif
+
     return MOS_STATUS_SUCCESS;
 }
 
@@ -1535,7 +1569,6 @@ MHW_SETPAR_DECL_SRC(MFX_PIPE_BUF_ADDR_STATE, AvcBasicFeature)
 
     ENCODE_CHK_STATUS_RETURN(m_ref->MHW_SETPAR_F(MFX_PIPE_BUF_ADDR_STATE)(params));
 
-#ifdef _MMC_SUPPORTED
     MOS_MEMCOMP_STATE reconSurfMmcState = MOS_MEMCOMP_DISABLED;
     if (m_mmcState->IsMmcEnabled())
     {
@@ -1561,7 +1594,7 @@ MHW_SETPAR_DECL_SRC(MFX_PIPE_BUF_ADDR_STATE, AvcBasicFeature)
 
     CODECHAL_DEBUG_TOOL(
         params.psPreDeblockSurface->MmcState = reconSurfMmcState;)
-#endif
+
     return MOS_STATUS_SUCCESS;
 }
 
