@@ -43,11 +43,8 @@ struct HevcFeatureIDs : public FeatureIDs
         vdencLplaAnalysisFeature,
         hevcVdencLplaEncFeature,
         hevcFullEncFeature,
-#if _MEDIA_RESERVED
-#define HEVC_FEATURE_IDS_EXT
-#include "media_hevc_feature_defs_ext.h"
-#undef HEVC_FEATURE_IDS_EXT
-#endif
+        hevcAqm,
+        hevcVdencFastPassFeature,
     };
 };
 
