@@ -97,7 +97,7 @@ MOS_STATUS EncodeScalabilityMultiPipe::AllocateSemaphore()
             &m_resSemaphoreOnePipeWait[i],
             &lockFlagsWriteOnly);
         SCALABILITY_CHK_NULL_RETURN(data);
-        *data = 1;
+        *data = 0;
         SCALABILITY_CHK_STATUS_RETURN(m_osInterface->pfnUnlockResource(
             m_osInterface,
             &m_resSemaphoreOnePipeWait[i]));
@@ -328,7 +328,7 @@ MOS_STATUS EncodeScalabilityMultiPipe::VerifySpaceAvailable(uint32_t requestedSi
     {
         SCALABILITY_CHK_STATUS_RETURN(MediaScalability::VerifySpaceAvailable(
             requestedSize, requestedPatchListSize, bothPatchListAndCmdBufChkSuccess));
-        if (bothPatchListAndCmdBufChkSuccess = true)
+        if (bothPatchListAndCmdBufChkSuccess == true)
         {
             singleTaskPhaseSupportedInPak = m_singleTaskPhaseSupported;
             return eStatus;
@@ -376,8 +376,7 @@ MOS_STATUS EncodeScalabilityMultiPipe::VerifyCmdBuffer(uint32_t requestedSize, u
         
         
         //Verify 2nd level BB;
-        uint32_t bufIdxPlus1 = m_singleTaskPhaseSupported ? currentPipeVerify : currentPipeVerify + m_pipeNum * m_currentPass;  //Make CMD buffer one next to one.
-        bufIdxPlus1 += 1;
+        uint32_t bufIdxPlus1 = currentPipeVerify + 1;  //Make CMD buffer one next to one.
         
         eStatus = MOS_STATUS_NO_SPACE;
         for (auto i = 0; (i < 3) && (eStatus != MOS_STATUS_SUCCESS); i++)
@@ -426,11 +425,9 @@ MOS_STATUS EncodeScalabilityMultiPipe::GetCmdBuffer(PMOS_COMMAND_BUFFER cmdBuffe
     }
 
     SCALABILITY_CHK_STATUS_RETURN(m_osInterface->pfnGetCommandBuffer(m_osInterface, &m_primaryCmdBuffer, 0));
-    uint32_t bufIdxPlus1 = m_singleTaskPhaseSupported ? m_currentPipe : m_currentPipe + m_pipeNum * m_currentPass;  //Make CMD buffer one next to one.
-    bufIdxPlus1 += 1;
+    uint32_t bufIdxPlus1 = m_currentPipe + 1;  //Make CMD buffer one next to one.
     m_osInterface->pfnGetCommandBuffer(m_osInterface, &m_secondaryCmdBuffer[bufIdxPlus1 - 1], bufIdxPlus1);
-
-    if (m_osInterface->apoMosEnabled)
+    if (m_osInterface->apoMosEnabled || m_osInterface->apoMosForLegacyRuntime)
     {
         int32_t submissionType = IsFirstPipe() ? SUBMISSION_TYPE_MULTI_PIPE_MASTER : SUBMISSION_TYPE_MULTI_PIPE_SLAVE;
         if (IsLastPipe())
@@ -483,10 +480,10 @@ MOS_STATUS EncodeScalabilityMultiPipe::ReturnCmdBuffer(PMOS_COMMAND_BUFFER cmdBu
         SCALABILITY_ASSERTMESSAGE("Verify Command buffer failed with invalid parameter:currentPass!");
         return eStatus;
     }
-    uint32_t bufIdxPlus1 = m_singleTaskPhaseSupported ? m_currentPipe : m_currentPipe + m_pipeNum * m_currentPass;  //Make CMD buffer one next to one.
-    bufIdxPlus1 += 1;
+    uint32_t bufIdxPlus1 = m_currentPipe + 1;  //Make CMD buffer one next to one.
     m_secondaryCmdBuffer[bufIdxPlus1 - 1] = *cmdBuffer;  //Need to record the iOffset, ptr and other data of CMD buffer, it's not maintain in the mos.
     m_osInterface->pfnReturnCommandBuffer(m_osInterface, &m_secondaryCmdBuffer[bufIdxPlus1 - 1], bufIdxPlus1);
+    m_primaryCmdBuffer.Attributes.bFrequencyBoost |= cmdBuffer->Attributes.bFrequencyBoost;
     m_osInterface->pfnReturnCommandBuffer(m_osInterface, &m_primaryCmdBuffer, 0);
     return eStatus;
 }
@@ -541,8 +538,7 @@ MOS_STATUS EncodeScalabilityMultiPipe::SubmitCmdBuffer(PMOS_COMMAND_BUFFER cmdBu
     // Add BB end for every secondary cmd buf when ready for submit
     for (uint32_t pipe = 0; pipe < m_pipeNum; pipe++)
     {
-        uint32_t bufIdxPlus1 = m_singleTaskPhaseSupported ? pipe : pipe + m_pipeNum * m_currentPass;
-        bufIdxPlus1 += 1;
+        uint32_t bufIdxPlus1 = pipe + 1;
 
         MOS_COMMAND_BUFFER& cmdBufferToAddBbEnd = m_secondaryCmdBuffer[bufIdxPlus1 - 1];
         SCALABILITY_CHK_STATUS_RETURN(m_osInterface->pfnGetCommandBuffer(m_osInterface, &cmdBufferToAddBbEnd, bufIdxPlus1));
@@ -684,11 +680,11 @@ MOS_STATUS EncodeScalabilityMultiPipe::ResetSemaphore(uint32_t syncType, uint32_
         }
         break;
     case syncOnePipeWaitOthers:
-        if (!Mos_ResourceIsNull(&m_resSemaphoreOnePipeWait[m_currentPipe]))
+        if (!Mos_ResourceIsNull(&m_resSemaphoreOnePipeWait[semaphoreId]))
         {
             SCALABILITY_CHK_STATUS_RETURN(
                 m_hwInterface->SendMiStoreDataImm(
-                    &m_resSemaphoreOnePipeWait[m_currentPipe],
+                    &m_resSemaphoreOnePipeWait[semaphoreId],
                     0,
                     cmdBuffer));
         }
@@ -725,7 +721,7 @@ MOS_STATUS EncodeScalabilityMultiPipe::UpdateState(void *statePars)
     SCALABILITY_FUNCTION_ENTER;
     MOS_STATUS   eStatus         = MOS_STATUS_SUCCESS;
     StateParams *encodeStatePars = (StateParams *)statePars;
-    if (encodeStatePars->currentPipe < 0 || encodeStatePars->currentPipe >= m_pipeNum)
+    if (encodeStatePars->currentPipe >= m_pipeNum)
     {
         eStatus = MOS_STATUS_INVALID_PARAMETER;
         SCALABILITY_ASSERTMESSAGE("UpdateState failed with invalid parameter:currentPipe!");
@@ -770,7 +766,7 @@ MOS_STATUS EncodeScalabilityMultiPipe::SendAttrWithFrameTracking(
 
     if (frameTrackingRequested && m_frameTrackingEnabled)
     {
-        m_statusReport->GetAddress(encode::statusReportGlobalCount, resource, offset);
+        ENCODE_CHK_STATUS_RETURN(m_statusReport->GetAddress(encode::statusReportGlobalCount, resource, offset));
         cmdBuffer.Attributes.bEnableMediaFrameTracking    = true;
         cmdBuffer.Attributes.resMediaFrameTrackingSurface = resource;
         cmdBuffer.Attributes.dwMediaFrameTrackingTag      = m_statusReport->GetSubmittedCount() + 1;
