@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2021, Intel Corporation
+* Copyright (c) 2021-2023, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -34,6 +34,7 @@
 #include "media_sfc_interface.h"
 #include "renderhal.h"
 #include "codechal_setting.h"
+#include "mhw_vdbox_vvcp_itf.h"
 
 #define HUC_DMEM_OFFSET_RTOS_GEMS 0x2000
 //------------------------------------------------------------------------------
@@ -108,6 +109,12 @@ public:
     //!
     virtual ~CodechalHwInterfaceNext();
 
+    static CodechalHwInterfaceNext* Create(
+        PMOS_INTERFACE     osInterface,
+        CODECHAL_FUNCTION  codecFunction,
+        MhwInterfacesNext* mhwInterfacesNext,
+        bool               disableScalability);
+
     //!
     //! \brief    Initialize the codechal hw interface
     //! \details  Initialize the interface before using
@@ -273,6 +280,17 @@ public:
         return m_renderItf;
     }
 
+    //!
+    //! \brief    Get vvcp interface
+    //! \details  Get vvcp interface in codechal hw interface next
+    //!
+    //! \return    pointer to new VVCP interface
+    //!
+    inline std::shared_ptr<mhw::vdbox::vvcp::Itf> GetVvcpInterfaceNext()
+    {
+        return m_vvcpItf;
+    }
+
     //!
     //! \brief    Get Os interface
     //! \details  Get Os interface in codechal hw interface
@@ -490,6 +508,51 @@ public:
         uint32_t *patchListSize,
         bool      modeSpecific);
 
+    //!
+    //! \brief    Calculates the maximum size for VVCP picture level commands
+    //! \details  Client facing function to calculate the maximum size for VVCP picture level commands
+    //! \param    [in] mode
+    //!           Indicate the codec mode
+    //! \param    [out] commandsSize
+    //!           The maximum command buffer size
+    //! \param    [out] patchListSize
+    //!           The maximum command patch list size
+    //! \param    [in] params
+    //!           Indicate the command size parameters
+    //! \return   MOS_STATUS
+    //!           MOS_STATUS_SUCCESS if success, else fail reason
+    //!
+    MOS_STATUS GetVvcpStateCommandSize(
+        uint32_t                        mode,
+        uint32_t                       *commandsSize,
+        uint32_t                       *patchListSize,
+        PMHW_VDBOX_STATE_CMDSIZE_PARAMS params);
+
+    //!
+    //! \brief    Calculates the size for VVCP slice level commands
+    //! \details  Client facing function to calculate the maximum size for VVCP picture level commands
+    //! \param    [in] mode
+    //!           Indicate the codec mode
+    //! \param    [out] sliceCommandsSize
+    //!           The maximum command buffer size for slice
+    //! \param    [out] slicePatchListSize
+    //!           The maximum command patch list size for slice
+    //! \param    [out] tileCommandsSize
+    //!           The maximum command buffer size for tile
+    //! \param    [out] tilePatchListSize
+    //!           The maximum command patch list size for tile
+    //! \return   MOS_STATUS
+    //!           MOS_STATUS_SUCCESS if success, else fail reason
+    //!
+    MOS_STATUS GetVvcpPrimitiveCommandSize(
+        uint32_t  mode,
+        uint32_t *sliceCommandsSize,
+        uint32_t *slicePatchListSize,
+        uint32_t *tileCommandsSize,
+        uint32_t *tilePatchListSize);
+
+    MOS_STATUS GetVvcpSliceLvlCmdSize(uint32_t *sliceLvlCmdSize);
+
     //!
     //! \brief    Add Huc stream out copy cmds
     //! \details  Prepare and add Huc stream out copy cmds
@@ -653,6 +716,41 @@ public:
         return false;
     }
 
+    //!
+    //! \brief    Send mi atomic dword cmd with indirect data (non-inline) mode
+    //! \details  Send mi atomic dword cmd for sync perpose
+    //!
+    //! \param    [in] resource
+    //!           Reource used in mi atomic dword cmd
+    //! \param    [in] opCode
+    //!           Operation code
+    //! \param    [in,out] cmdBuffer
+    //!           command buffer
+    //!
+    //! \return   MOS_STATUS
+    //!           MOS_STATUS_SUCCESS if success, else fail reason
+    //!
+    MOS_STATUS SendMiAtomicDwordIndirectDataCmd(
+        PMOS_RESOURCE               resource,
+        MHW_COMMON_MI_ATOMIC_OPCODE opCode,
+        PMOS_COMMAND_BUFFER         cmdBuffer)
+    {
+        MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
+
+        CODEC_HW_FUNCTION_ENTER;
+        CODEC_HW_CHK_NULL_RETURN(m_miItf);
+
+        auto &params             = m_miItf->MHW_GETPAR_F(MI_ATOMIC)();
+        params                   = {};
+        params.pOsResource       = resource;
+        params.dwDataSize        = sizeof(uint32_t);
+        params.Operation         = (mhw::mi::MHW_COMMON_MI_ATOMIC_OPCODE) opCode;
+        params.bInlineData       = false;
+        eStatus                  = m_miItf->MHW_ADDCMD_F(MI_ATOMIC)(cmdBuffer);
+
+        return eStatus;
+    }
+
     //!
     //! \brief    Send mi atomic dword cmd
     //! \details  Send mi atomic dword cmd for sync perpose
@@ -902,7 +1000,7 @@ protected:
     std::shared_ptr<mhw::vdbox::mfx::Itf>    m_mfxItf   = nullptr;      //!< Pointer to Mhw mfx interface
     std::shared_ptr<mhw::render::Itf>        m_renderItf   = nullptr;      //!< Pointer to render interface
     std::shared_ptr<MediaSfcInterface>       m_mediaSfcItf = nullptr;      //!< Pointer to Media sfc interface
-
+    std::shared_ptr<mhw::vdbox::vvcp::Itf>   m_vvcpItf     = nullptr;
     // States
     PMOS_INTERFACE       m_osInterface;  //!< Pointer to OS interface
 
