@@ -191,6 +191,9 @@ public:
 
         if (m_veboxHeap)
         {
+#if (_DEBUG || _RELEASE_INTERNAL)
+            ReportVeboxId();
+#endif
             if (!Mos_ResourceIsNull(&m_veboxHeap->DriverResource))
             {
                 if (m_veboxHeap->pLockedDriverResourceMem)
@@ -273,7 +276,13 @@ public:
 
         m_veboxHeap->uiHdrStateOffset = uiOffset;
         uiOffset += m_veboxSettings.uiHdrStateSize;
-
+#if (_DEBUG || _RELEASE_INTERNAL)
+        if (m_veboxIdReportEnabled)
+        {
+            m_veboxHeap->uiEngineDataOffset = uiOffset;
+            uiOffset += m_veboxSettings.uiEngineDataSize;
+        }
+#endif
         m_veboxHeap->uiInstanceSize = uiOffset;
 
         // Appending VeboxHeap sync data after all vebox heap instances
@@ -429,7 +438,8 @@ public:
             // The condition below is valid when sync tag wraps from 2^32-1 to 0
             if (((int32_t)(dwCurrentTag - pCurInstance->dwSyncTag) >= 0) ||
                 NullRenderingFlags.VPGobal ||
-                NullRenderingFlags.VPDnDi)
+                NullRenderingFlags.VPDnDi  ||
+                this->m_osItf->bNullHwIsEnabled)
             {
                 pCurInstance->bBusy = false;
             }
@@ -569,8 +579,24 @@ public:
         pVeboxHeap->uiNextState = (pVeboxHeap->uiNextState + 1) %
             (m_veboxSettings.uiNumInstances);
 
-        //Clean the memory of current veboxheap to avoid the history states
         uiOffset = pVeboxHeap->uiCurState * pVeboxHeap->uiInstanceSize;
+#if (_DEBUG || _RELEASE_INTERNAL)
+        if (m_veboxIdReportEnabled)
+        {
+            if (pVeboxCurState->engineData && MHW_VEBOX_ENGINE_CLASS_ID ==(*pVeboxCurState->engineData).classId)
+            {
+                // Record old engine instance id before memory clearance when reusing heap state
+                m_usedVeboxID |= 1 << (*pVeboxCurState->engineData).instanceId;
+            }
+            if (nullptr == pVeboxCurState->engineData)
+            {
+                pVeboxCurState->engineData =
+                    (MHW_VEBOX_ENGINE_DATA*)(pVeboxHeap->pLockedDriverResourceMem + uiOffset +
+                        pVeboxHeap->uiEngineDataOffset);
+            }
+        }
+#endif
+        //Clean the memory of current veboxheap to avoid the history states
         MOS_ZeroMemory(pVeboxHeap->pLockedDriverResourceMem + uiOffset, pVeboxHeap->uiInstanceSize);
 
         return eStatus;
@@ -640,7 +666,9 @@ public:
             *pdwSurfaceWidth = MOS_ALIGN_CEIL(
                 MOS_MIN(pCurrSurf->dwWidth, MOS_MAX((uint32_t)pCurrSurf->rcSrc.right, MHW_VEBOX_MIN_WIDTH)),
                 wWidthAlignUnit);
-            MHW_NORMALMESSAGE("bVEBOXCroppingUsed = true, SurfInput.rcSrc.bottom: %d, par.SurfInput.rcSrc.right: %d; pdwSurfaceHeight: %d, pdwSurfaceWidth: %d;",
+            MHW_NORMALMESSAGE("bVEBOXCroppingUsed = true, SurfInput.dwWidth: %d, SurfInput.dwHeight: %d, SurfInput.rcSrc.bottom: %d, par.SurfInput.rcSrc.right: %d; pdwSurfaceHeight: %d, pdwSurfaceWidth: %d;",
+                pCurrSurf->dwWidth,
+                pCurrSurf->dwHeight,
                 (uint32_t)pCurrSurf->rcSrc.bottom,
                 (uint32_t)pCurrSurf->rcSrc.right,
                 *pdwSurfaceHeight,
@@ -661,13 +689,29 @@ public:
             *pdwSurfaceWidth = MOS_ALIGN_CEIL(
                 MOS_MIN(pCurrSurf->dwWidth, MOS_MAX((uint32_t)pCurrSurf->rcMaxSrc.right, MHW_VEBOX_MIN_WIDTH)),
                 wWidthAlignUnit);
-            MHW_NORMALMESSAGE("bVEBOXCroppingUsed = false, SurfInput.rcMaxSrc.bottom: %d, SurfInput.rcMaxSrc.right: %d; pdwSurfaceHeight: %d, pdwSurfaceWidth: %d;",
+            MHW_NORMALMESSAGE("bVEBOXCroppingUsed = false, SurfInput.dwWidth: %d, SurfInput.dwHeight: %d, SurfInput.rcMaxSrc.bottom: %d, SurfInput.rcMaxSrc.right: %d; pdwSurfaceHeight: %d, pdwSurfaceWidth: %d;",
+                pCurrSurf->dwWidth,
+                pCurrSurf->dwHeight,
                 (uint32_t)pCurrSurf->rcMaxSrc.bottom,
                 (uint32_t)pCurrSurf->rcMaxSrc.right,
                 *pdwSurfaceHeight,
                 *pdwSurfaceWidth);
         }
 
+        if (m_forceInputHeight8Aligned)
+        {
+            if (wHeightAlignUnit <= 8 && MOS_ALIGN_CEIL(*pdwSurfaceHeight, 8) <= pCurrSurf->dwHeight)
+            {
+                MHW_NORMALMESSAGE("Vebox input height updated from %d to %d by force 8 aligned, pCurrSurf->dwHeight %d, wHeightAlignUnit %d",
+                    *pdwSurfaceHeight, MOS_ALIGN_CEIL(*pdwSurfaceHeight, 8), pCurrSurf->dwHeight, wHeightAlignUnit);
+                *pdwSurfaceHeight = MOS_ALIGN_CEIL(*pdwSurfaceHeight, 8);
+            }
+            else
+            {
+                MHW_ASSERTMESSAGE("Invalid parameter for forceInputHeight8Aligned, pdwSurfaceHeight %d, pdwSurfaceHeight w/ 8 aligned %d, pCurrSurf->dwHeight %d, wHeightAlignUnit %d",
+                    *pdwSurfaceHeight, MOS_ALIGN_CEIL(*pdwSurfaceHeight, 8), pCurrSurf->dwHeight, wHeightAlignUnit);
+            }
+        }
         return eStatus;
     }
 
@@ -863,6 +907,46 @@ public:
 
         return eStatus;
     }
+
+    bool IsVeboxIdReportEnabled() override
+    {
+        return m_veboxIdReportEnabled;
+    }
+
+    MOS_STATUS ReportVeboxId() override
+    {
+        if (m_veboxIdReportEnabled)
+        {
+            MHW_CHK_NULL_RETURN(m_veboxHeap);
+            MHW_CHK_NULL_RETURN(m_veboxHeap->pStates);
+            uint32_t reportedUsedID = 0;
+            for (uint32_t index = 0; index < m_veboxSettings.uiNumInstances; index++)
+            {
+                const MHW_VEBOX_HEAP_STATE &curInstance = m_veboxHeap->pStates[index];
+                if (curInstance.engineData && MHW_VEBOX_ENGINE_CLASS_ID == (*curInstance.engineData).classId)
+                {
+                    m_usedVeboxID |= 1 << (*curInstance.engineData).instanceId;
+                }
+            }
+            // It is only used in debugging scenarios for multi-Vebox platforms.
+            // No need to add any locks here.
+            // This approach can handle all current debugging scenarios with multiple threads/processes.
+            ReadUserSettingForDebug(
+                m_userSettingPtr,
+                reportedUsedID,
+                __MEDIA_USER_FEATURE_VALUE_USED_VEBOX_ID,
+                MediaUserSetting::Group::Sequence,
+                0,
+                false,
+                MEDIA_USER_SETTING_INTERNAL_REPORT);
+            ReportUserSettingForDebug(
+                m_userSettingPtr,
+                __MEDIA_USER_FEATURE_VALUE_USED_VEBOX_ID,
+                reportedUsedID | m_usedVeboxID,
+                MediaUserSetting::Group::Sequence);
+        }
+        return MOS_STATUS_SUCCESS;
+    }
 #endif
 
     MOS_STATUS VeboxAdjustBoundary(
@@ -887,6 +971,12 @@ public:
         return eStatus;
     }
 
+    void SetForceInputHeight8AlignedFlag(bool forceInputHeight8Aligned) override
+    {
+        MHW_NORMALMESSAGE("SetForceInputHeight8AlignedFlag %d->%d", forceInputHeight8Aligned, m_forceInputHeight8Aligned);
+        m_forceInputHeight8Aligned = forceInputHeight8Aligned;
+    }
+
     MOS_STATUS FindVeboxGpuNodeToUse(
         PMHW_VEBOX_GPUNODE_LIMIT pGpuNodeLimit) override
     {
@@ -1030,6 +1120,7 @@ protected:
     bool                      bHVSAutoBdrateEnable        = false;
     bool                      bHVSAutoSubjectiveEnable    = false;
     bool                      bHVSfallback                = false;
+    bool                      m_forceInputHeight8Aligned  = false;
 
     MHW_VEBOX_HEAP            *m_veboxHeap                = nullptr;
     MHW_VEBOX_SETTINGS        m_veboxSettings             = {};
@@ -1043,7 +1134,10 @@ protected:
     MHW_VEBOX_GAMUT_PARAMS  m_veboxGamutParams = {};
 
     int                    m_veboxHeapInUse = 0;
-
+#if (_DEBUG || _RELEASE_INTERNAL)
+    bool                   m_veboxIdReportEnabled = false;
+    uint32_t               m_usedVeboxID = 0;
+#endif
 MEDIA_CLASS_DEFINE_END(mhw__vebox__Impl)
 };
 }  // namespace render
