@@ -427,7 +427,6 @@ MOS_STATUS MediaDebugInterface::DumpMosSpecificResourceInfoToOfs(
             FIELD_TO_OFS_8SHIFT(Info.KernelModeMapped);
             FIELD_TO_OFS_8SHIFT(Info.LayoutBelow);
             FIELD_TO_OFS_8SHIFT(Info.LayoutMono);
-            FIELD_TO_OFS_8SHIFT(Info.LayoutRight);
             FIELD_TO_OFS_8SHIFT(Info.LocalOnly);
             FIELD_TO_OFS_8SHIFT(Info.Linear);
             FIELD_TO_OFS_8SHIFT(Info.MediaCompressed);
@@ -612,7 +611,7 @@ MOS_STATUS MediaDebugInterface::ReAllocateSurface(
         &allocParams,
         &pSurface->OsResource));
 
-    if (!m_osInterface->apoMosEnabled)
+    if (!m_osInterface->apoMosEnabled && !m_osInterface->apoMosForLegacyRuntime)
     {
         MOS_SURFACE details;
         MOS_ZeroMemory(&details, sizeof(details));
