@@ -751,6 +751,7 @@ MOS_STATUS SwFilterPipe::AddSwFilterOrdered(SwFilter *swFilter, bool isInputPipe
 
     VP_PUBLIC_CHK_STATUS_RETURN(pSubPipe->AddSwFilterOrdered(swFilter, useNewSwFilterSet));
     swFilter->SetExePipeFlag(m_isExePipe);
+    m_gpuCtxOnHybridCmd |= swFilter->GetGpuCtxOnHybridCmd();
 
     return MOS_STATUS_SUCCESS;
 }
@@ -783,6 +784,7 @@ MOS_STATUS SwFilterPipe::AddSwFilterUnordered(SwFilter *swFilter, bool isInputPi
 
     VP_PUBLIC_CHK_STATUS_RETURN(pSubPipe->AddSwFilterUnordered(swFilter));
     swFilter->SetExePipeFlag(m_isExePipe);
+    m_gpuCtxOnHybridCmd |= swFilter->GetGpuCtxOnHybridCmd();
 
     return MOS_STATUS_SUCCESS;
 }
@@ -1060,7 +1062,7 @@ MOS_STATUS RemoveUnusedLayers(std::vector<uint32_t> &indexForRemove, std::vector
             {
                 VP_PUBLIC_CHK_STATUS_RETURN(MOS_STATUS_INVALID_PARAMETER);
             }
-            objForRemove.insert(std::make_pair(layers[index], layers[index]));
+            objForRemove.emplace(layers[index], layers[index]);
             layers[index] = nullptr;
         }
         for (auto it : objForRemove)
