@@ -27,11 +27,12 @@
 //!
 #include "vp_kernelset.h"
 #include "vp_render_fc_kernel.h"
-#include "vp_render_l0_fc_kernel.h"
+#include "vp_render_ocl_fc_kernel.h"
 #include "vp_render_vebox_hdr_3dlut_kernel.h"
 #include "vp_render_vebox_hvs_kernel.h"
 #include "vp_render_hdr_kernel.h"
-#include "vp_render_vebox_hdr_3dlut_l0_kernel.h"
+#include "vp_render_vebox_hdr_3dlut_ocl_kernel.h"
+#include "vp_render_ai_kernel.h"
 
 using namespace vp;
 
@@ -116,8 +117,9 @@ MOS_STATUS VpKernelSet::FindAndInitKernelObj(VpRenderKernelObj* kernelObj)
 
 MOS_STATUS VpKernelSet::CreateSingleKernelObject(
     VpRenderKernelObj *&kernel,
-    VpKernelID kernelId,
-    KernelIndex kernelIndex)
+    VpKernelID          kernelId,
+    KernelIndex         kernelIndex,
+    std::string         kernelName)
 {
     VP_FUNC_CALL();
     kernel = nullptr;
@@ -127,11 +129,14 @@ MOS_STATUS VpKernelSet::CreateSingleKernelObject(
         kernel = (VpRenderKernelObj*)MOS_New(VpRenderFcKernel, m_hwInterface, m_allocator);
         VP_RENDER_CHK_NULL_RETURN(kernel);
         break;
-    case kernelL0FcCommon:
-    case kernelL0FcFP:
-    case kernelL0Fc420PL3Input:
-    case kernelL0Fc444PL3Input:
-        kernel = (VpRenderKernelObj *)MOS_New(VpRenderL0FcKernel, m_hwInterface, kernelId, kernelIndex, m_allocator);
+    case kernelOclFcCommon:
+    case kernelOclFcFP:
+    case kernelOclFc420PL3Input:
+    case kernelOclFc420PL3Output:
+    case kernelOclFc444PL3Input:
+    case kernelOclFc444PL3Output:
+    case kernelOclFc422HVInput:
+        kernel = (VpRenderKernelObj *)MOS_New(VpRenderOclFcKernel, m_hwInterface, kernelId, kernelIndex, m_allocator);
         VP_RENDER_CHK_NULL_RETURN(kernel);
         break;
     case kernelHdr3DLutCalc:
@@ -147,9 +152,9 @@ MOS_STATUS VpKernelSet::CreateSingleKernelObject(
         }
         VP_RENDER_CHK_NULL_RETURN(kernel);
         break;
-    case kernelHdr3DLutCalcL0:
-        VP_RENDER_NORMALMESSAGE("HDR 3dlut kernel use l0 fillLutTable_3dlut kernel");
-        kernel = (VpRenderKernelObj *)MOS_New(VpRenderHdr3DLutL0Kernel, m_hwInterface, m_allocator);
+    case kernelHdr3DLutCalcOcl:
+        VP_RENDER_NORMALMESSAGE("HDR 3dlut kernel use ocl fillLutTable_3dlut kernel");
+        kernel = (VpRenderKernelObj *)MOS_New(VpRenderHdr3DLutOclKernel, m_hwInterface, m_allocator);
         VP_RENDER_CHK_NULL_RETURN(kernel);
         break;
     case kernelHVSCalc:
@@ -160,6 +165,10 @@ MOS_STATUS VpKernelSet::CreateSingleKernelObject(
         kernel = (VpRenderKernelObj *)MOS_New(VpRenderHdrKernel, m_hwInterface, m_allocator);
         VP_RENDER_CHK_NULL_RETURN(kernel);
         break;
+    case kernelAiCommon:
+        kernel = (VpRenderKernelObj *)MOS_New(VpRenderAiKernel, m_hwInterface, kernelName, kernelIndex, m_allocator);
+        VP_RENDER_CHK_NULL_RETURN(kernel);
+        break;
     default:
         VP_RENDER_ASSERTMESSAGE("No supported kernel, return");
         return MOS_STATUS_UNIMPLEMENTED;
@@ -208,7 +217,8 @@ MOS_STATUS VpKernelSet::CreateKernelObjects(
             VP_RENDER_CHK_STATUS_RETURN(CreateSingleKernelObject(
                 kernel,
                 kernelParams[kernelIndex].kernelId,
-                kernelIndex));
+                kernelIndex,
+                kernelParams[kernelIndex].kernelName));
             if (kernel->IsKernelCached())
             {
                 m_cachedKernels.insert(std::make_pair(kernelParams[kernelIndex].kernelId, kernel));
@@ -232,7 +242,7 @@ MOS_STATUS VpKernelSet::CreateKernelObjects(
 
             VP_RENDER_CHK_STATUS_RETURN(VpStatusHandler(kernel->InitKernel(binary, kernelSize, kernelConfigs, surfacesGroup, surfMemCacheCtl)));
 
-            kernelObjs.insert(std::make_pair(kernelIndex, kernel));
+            kernelObjs.emplace(kernelIndex, kernel);
         }
         else
         {
@@ -240,7 +250,7 @@ MOS_STATUS VpKernelSet::CreateKernelObjects(
 
             VP_RENDER_CHK_STATUS_RETURN(VpStatusHandler(kernel->SetKernelConfigs(kernelParams[kernelIndex], surfacesGroup, samplerStateGroup, kernelConfigs, sharedContext)));
 
-            kernelObjs.insert(std::make_pair(kernelIndex, kernel));
+            kernelObjs.emplace(kernelIndex, kernel);
         }
     }
 
