@@ -270,6 +270,13 @@ struct _VEBOX_PROCAMP_PARAMS
     float                           fSaturation;
 };
 
+enum class VEBOX_CSC_BLOCK_TYPE
+{
+    DEFAULT,
+    BACK_END,
+    FRONT_END
+};
+
 struct _VEBOX_CSC_PARAMS
 {
     bool                            bCSCEnabled;                                 // CSC Enabled
@@ -284,6 +291,7 @@ struct _VEBOX_CSC_PARAMS
     uint32_t                        chromaUpSamplingHorizontalCoef;              // Chroma UpSampling Horizontal Coeff
     uint32_t                        chromaDownSamplingVerticalCoef;              // Chroma DownSampling Vertical Coeff
     uint32_t                        chromaDownSamplingHorizontalCoef;            // Chroma DownSampling Horizontal Coeff
+    VEBOX_CSC_BLOCK_TYPE            blockType;                                   // Use Back End CSC or Front End CSC
 };
 
 struct _RENDER_CSC_PARAMS
@@ -461,6 +469,62 @@ struct _RENDER_FC_PARAMS
 using RENDER_FC_PARAMS  = _RENDER_FC_PARAMS;
 using PRENDER_FC_PARAMS = RENDER_FC_PARAMS *;
 
+
+struct OCL_FC_KERNEL_CONFIG
+{
+    VPHAL_PERFTAG perfTag = VPHAL_NONE;
+};
+
+struct OCL_FC_KERNEL_PARAM
+{
+    KERNEL_ARGS                  kernelArgs;
+    std::string                  kernelName;
+    VpKernelID                   kernelId;
+    uint32_t                     threadWidth;
+    uint32_t                     threadHeight;
+    uint32_t                     localWidth;
+    uint32_t                     localHeight;
+    KERNEL_ARG_INDEX_SURFACE_MAP kernelStatefulSurfaces;
+    OCL_FC_KERNEL_CONFIG         kernelConfig;
+    void                         Init();
+};
+
+using OCL_FC_KERNEL_PARAMS = std::vector<OCL_FC_KERNEL_PARAM>;
+struct _RENDER_OCL_FC_PARAMS
+{
+    OCL_FC_KERNEL_PARAMS fc_kernelParams = {};
+    void                 Init();
+};
+using RENDER_OCL_FC_PARAMS  = _RENDER_OCL_FC_PARAMS;
+using PRENDER_OCL_FC_PARAMS = RENDER_OCL_FC_PARAMS *;
+
+struct AI_KERNEL_CONFIG
+{
+    VPHAL_PERFTAG            perfTag     = VPHAL_NONE;
+};
+
+struct AI_KERNEL_PARAM
+{
+    KERNEL_ARGS                  kernelArgs;
+    std::string                  kernelName;
+    uint32_t                     threadWidth;
+    uint32_t                     threadHeight;
+    uint32_t                     localWidth;
+    uint32_t                     localHeight;
+    KERNEL_ARG_INDEX_SURFACE_MAP kernelStatefulSurfaces;
+    void                         Init();
+};
+
+using AI_KERNEL_PARAMS = std::vector<AI_KERNEL_PARAM>;
+struct _RENDER_AI_PARAMS
+{
+    AI_KERNEL_PARAMS ai_kernelParams = {};
+    AI_KERNEL_CONFIG ai_kernelConfig = {};
+    void             Init();
+};
+using RENDER_AI_PARAMS  = _RENDER_AI_PARAMS;
+using PRENDER_AI_PARAMS = RENDER_AI_PARAMS *;
+
 struct _RENDER_HDR_PARAMS
 {
     VpKernelID              kernelId;
@@ -596,7 +660,7 @@ public:
     virtual MOS_STATUS UpdateUnusedFeature(VP_EXECUTE_CAPS caps, SwFilter &feature, SwFilterPipe &featurePipe, SwFilterPipe &executePipe, bool isInputPipe, int index);
     FeatureType GetType();
     HwFilterParameter *GetHwFeatureParameterFromPool();
-    MOS_STATUS ReleaseHwFeatureParameter(HwFilterParameter *&pParam);
+    virtual MOS_STATUS ReleaseHwFeatureParameter(HwFilterParameter *&pParam);
 protected:
     FeatureType m_Type = FeatureTypeInvalid;
     std::vector<HwFilterParameter *> m_Pool;
