@@ -49,6 +49,7 @@ public:
     }
 
     MOS_STATUS SetEuThreadSchedulingMode(uint32_t mode);
+    MOS_STATUS SetLargeGrfMode(uint32_t mode);
 
     virtual MOS_STATUS Submit(MOS_COMMAND_BUFFER* commandBuffer, uint8_t packetPhase = otherPacket) override;
 
@@ -93,6 +94,8 @@ protected:
 
     virtual MOS_STATUS SetupCurbeState();
 
+    virtual MOS_STATUS SetupCurbeStateInBindlessMode();
+
     virtual VP_SURFACE* GetSurface(SurfaceType type);
 
     virtual MOS_STATUS SetupWalkerParams();
