@@ -87,8 +87,8 @@ using KERNEL_SAMPLER_INDEX = std::vector<SamplerIndex>;
 using KERNEL_SURFACE_CONFIG = std::map<SurfaceType, KERNEL_SURFACE_STATE_PARAM>;
 using KERNEL_SURFACE_BINDING_INDEX = std::map<SurfaceType, std::set<uint32_t>>;
 using KERNEL_STATELESS_BUFF_CONFIG = std::map<SurfaceType, uint64_t>;
-using KERNEL_BINDELESS_SURFACE = std::map<SurfaceType, std::set<uint32_t>>;
-using KERNEL_BINDELESS_SAMPLER = std::map<uint32_t, uint32_t>;
+using KERNEL_BINDELESS_SURFACE = std::map<SurfaceType, std::vector<uint64_t>>;
+using KERNEL_BINDELESS_SAMPLER = std::map<uint32_t, uint64_t>;
 
 typedef struct _KERNEL_PARAMS
 {
@@ -460,7 +460,7 @@ public:
         {
             std::set<uint32_t> bindingMap;
             bindingMap.insert(index);
-            m_surfaceBindingIndex.insert(std::make_pair(surface, bindingMap));
+            m_surfaceBindingIndex.emplace(surface, bindingMap);
         }
 
         return MOS_STATUS_SUCCESS;
@@ -474,7 +474,7 @@ public:
         {
             VP_RENDER_ASSERTMESSAGE("No surface index created for current surface");
             std::set<uint32_t> bindingMap;
-            it = m_surfaceBindingIndex.insert(std::make_pair(surface, bindingMap)).first;
+            it = m_surfaceBindingIndex.emplace(surface, bindingMap).first;
         }
         return it->second;
     }
@@ -525,21 +525,34 @@ public:
         return 0;
     }
 
+    virtual uint32_t GetLargeGrfMode()
+    {
+        //by default not enable
+        //control all the kernels in BB, cannot only enable for one kernel in BB
+        return 0;
+    }
+
     virtual MOS_STATUS InitRenderHalSurfaceCMF(MOS_SURFACE* src, PRENDERHAL_SURFACE renderHalSurface);
 
-    virtual MOS_STATUS SetInlineDataParameter(KRN_ARG args, RENDERHAL_INTERFACE *renderhal);
-
-    virtual MOS_STATUS UpdateBindlessSurfaceResource(SurfaceType surf, std::set<uint32_t> surfStateOffset)
+    virtual MOS_STATUS UpdateBindlessSurfaceResource(SurfaceType surf, std::vector<uint64_t> stateGfxAddress)
     {
-        if (surf != SurfaceTypeInvalid)
+        if (surf != SurfaceTypeInvalid && surf != SurfaceTypeSubPlane)
         {
-            m_bindlessSurfaceArray.insert(std::make_pair(surf, surfStateOffset));
+            auto handle = m_bindlessSurfaceArray.find(surf);
+            if (handle == m_bindlessSurfaceArray.end())
+            {
+                m_bindlessSurfaceArray.insert(std::make_pair(surf, stateGfxAddress));
+            }
+            else
+            {
+                handle->second = stateGfxAddress;
+            }
         }
 
         return MOS_STATUS_SUCCESS;
     }
 
-    virtual std::map<uint32_t, uint32_t>& GetBindlessSamplers()
+    virtual std::map<uint32_t, uint64_t>& GetBindlessSamplers()
     {
         return m_bindlessSamperArray;
     }
@@ -551,6 +564,12 @@ public:
         return MOS_STATUS_SUCCESS;
     }
 
+    virtual MOS_STATUS SetCurbeGfxAddress(uint64_t address)
+    {
+        m_curbeGfxAddress = address;
+        return MOS_STATUS_SUCCESS;
+    }
+
 protected:
 
     virtual MOS_STATUS SetWalkerSetting(KERNEL_THREAD_SPACE &threadSpace, bool bSyncFlag, bool flushL1 = false);
@@ -581,6 +600,11 @@ protected:
 
     virtual MOS_STATUS SetTuningFlag(PKERNEL_TUNING_PARAMS tuningParams);
 
+    virtual MOS_STATUS SetInlineDataParameter(KRN_ARG arg, uint8_t *inlineData);
+
+    virtual MOS_STATUS GetBindlessSamplerGfxAddress(uint32_t samplerIndex, uint64_t &address);
+    virtual MOS_STATUS GetBindlessSurfaceStateGfxAddress(KRN_ARG &arg, uint64_t &address);
+
 protected:
 
     VP_SURFACE_GROUP                                        *m_surfaceGroup = nullptr;  // input surface process surface groups
@@ -601,6 +625,7 @@ protected:
     VpKernelID                                              m_kernelId = kernelCombinedFc;
     DelayLoadedKernelType                                   m_kernelType     = KernelNone;
     KernelIndex                                             m_kernelIndex = 0;          // index of current kernel in KERNEL_PARAMS_LIST
+    uint64_t                                                m_curbeGfxAddress   = 0;
 
     PKERNEL_TUNING_PARAMS                                   m_kernelTuningParams = nullptr;
 
@@ -608,7 +633,6 @@ protected:
     bool                                                    m_useIndependentSamplerGroup = false; //true means multi kernels has their own stand alone sampler states group. only can be true when m_isAdvKernel is true.
 
     std::shared_ptr<mhw::vebox::Itf>                        m_veboxItf = nullptr;
-    std ::vector<MHW_INLINE_DATA_PARAMS>                    m_inlineDataParams = {};
 
     KERNEL_ARG_INDEX_SURFACE_MAP                            m_argIndexSurfMap = {};
 
