@@ -1,4 +1,4 @@
-/* Copyright (c) 2022, Intel Corporation
+/* Copyright (c) 2022-2024, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -154,7 +154,7 @@ public:
     //! \details  Set mmc parameters
     //! \param    [in] renderTarget
     //!           render target surface
-    //! \param    [in] isFormalMmcSupported
+    //! \param    [in] isFormatMmcSupported
     //!           Is format supported by mmc
     //! \param    [in] isMmcEnabled
     //!           Is mmc enabled
@@ -441,16 +441,12 @@ protected:
     //! \details  Allocate line buffer
     //! \param    [in/out] lineBufferArray
     //!           pointer to line buffer.
-    //! \param    [in] numPipe
-    //!           size of pipe.
-    //! \param    [in] size
-    //!           size of line buffer.
-    //! \param    [in] bufName
-    //!           name of line buffer.
+    //! \param    [in] count
+    //!           count of line buffer.
     //! \return   MOS_STATUS
     //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
     //!
-    MOS_STATUS DestroyLineBufferArray(VP_SURFACE **&lineBufferArray);
+    MOS_STATUS DestroyLineBufferArray(VP_SURFACE **&lineBufferArray, int32_t count);
 
     //!
     //! \brief    Allocate Resources for SFC Pipe
@@ -579,6 +575,11 @@ protected:
 
     bool                            m_disableSfcDithering = false;
 
+    VP_SURFACE                      **m_AVSLineBufferSurfaceArrayfor1stPassofSfc2Pass = nullptr;  //!< AVS Line Buffer Surface for SFC 1st Pass of Sfc 2Pass
+    VP_SURFACE                      **m_IEFLineBufferSurfaceArrayfor1stPassofSfc2Pass = nullptr;  //!< IEF Line Buffer Surface for SFC 1st Pass of Sfc 2Pass
+    VP_SURFACE                      **m_SFDLineBufferSurfaceArrayfor1stPassofSfc2Pass = nullptr;  //!< SFD Line Buffer Surface for SFC 1st Pass of Sfc 2Pass
+    int                             m_lineBufferAllocatedInArrayfor1stPassofSfc2Pass  = 1;        //!< Line buffer allocated in array for SFC 1st Pass of Sfc 2Pass
+
 MEDIA_CLASS_DEFINE_END(vp__SfcRenderBase)
 };
 
