@@ -72,9 +72,12 @@ public:
         uint8_t                       rtCacheSetting      = 0;                            //!< Render Target cache usage
 #if (_DEBUG || _RELEASE_INTERNAL)
         uint8_t                       rtOldCacheSetting   = 0;                            //!< Render Target old cache usage
-        bool                          isL03DLut           = false;
-        bool                          isL0FC              = false;
-        uint32_t                      diffLogL0FC         = 0;
+        bool                          isOcl3DLut          = false;
+        bool                          isOclFC             = false;
+        uint32_t                      diffLogOclFC        = 0;
+        uint32_t                      featureLogOclFC     = 0;
+        bool                          isLegacyFCInUse     = false;
+        bool                          fallbackScalingToRender8K = false;
 #endif
         bool                          VeboxScalability    = false;                        //!< Vebox Scalability flag
         bool                          VPApogeios          = false;                        //!< VP Apogeios flag
