@@ -22,9 +22,19 @@
 #ifndef __VP_PIPELINE_ADAPTER_H__
 #define __VP_PIPELINE_ADAPTER_H__
 
-#include "vphal.h"
 #include "vp_pipeline.h"
 #include "vp_pipeline_common.h"
+#include "vp_pipeline_adapter_base.h"
+
+const SseuSetting VpHalDefaultSSEUTable[baseKernelMaxNumID] =
+    {
+        // Slice    Sub-Slice       EU      Rsvd(freq)
+        {2, 3, 8, 0},  // COMBINED_FC_KERNEL Default
+
+        // 2 VEBOX KERNELS
+        {2, 3, 8, 0},  // VEBOX_SECUREBLOCKCOPY_KERNEL,
+        {2, 3, 8, 0},  // VEBOX_UPDATEDNSTATE_KERNEL,
+};
 
 class VpPipelineAdapter : public VpPipelineAdapterBase
 {
@@ -63,7 +73,7 @@ public:
     //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
     //!
     virtual MOS_STATUS Allocate(
-      const VphalSettings     *pVpHalSettings) = 0;
+        const VpSettings *pVpHalSettings) = 0;
 
     //!
     //! \brief    Get Status Report
@@ -97,6 +107,10 @@ public:
     virtual MOS_STATUS Execute(PVP_PIPELINE_PARAMS params) = 0;
 
     virtual void Destroy();
+    virtual bool IsOclFCEnabled()
+    {
+        return m_vpPipeline->IsOclFCEnabled();
+    }
 
 protected:
     //!
@@ -110,7 +124,7 @@ protected:
     //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
     //!
     virtual MOS_STATUS Init(
-      const VphalSettings *pVpHalSettings, VP_MHWINTERFACE vpMhwinterface);
+        const VpSettings *pVpHalSettings, VP_MHWINTERFACE vpMhwinterface);
 
     //!
     //! \brief  Finish the execution for each frame
